@@ -40,14 +40,15 @@ def aggregate_queries(query_infos):
                                                       f'No dataset resolved for '
                                                       f'measure={coordinate.measure} with '
                                                       f'dimensions={coordinate.dimensions}')
-            query_info.processor.calculate(query_info.attr, series)
+            query_info.processor.calculate(query_info.attr, series, None)
             continue
         dataset_mappings.setdefault(query_key, {
             'datasetId': dataset_id,
             'parameters': {},
             'queries': defaultdict(list),
             'range': {},
-            'realTime': True if coordinate.frequency == DataFrequency.REAL_TIME else False
+            'realTime': True if coordinate.frequency == DataFrequency.REAL_TIME else False,
+            'measures': set()
         })
         query_map = dataset_mappings[query_key]
         if not query_map['range']:
@@ -64,6 +65,7 @@ def aggregate_queries(query_infos):
         queries = query_map['queries']
         queries[coordinate.get_dimensions()].append(query_info)
         parameters = query_map['parameters']
+        query_map['measures'].add(coordinate.measure)
         for dimension, value in coordinate.dimensions.items():
             parameters.setdefault(dimension, set())
             parameters[dimension].add(value)
@@ -74,10 +76,18 @@ def aggregate_queries(query_infos):
 def fetch_query(query_info: Dict):
     where = {}
     for key, value in query_info['parameters'].items():
+        value_list = list(value)
+        if isinstance(value_list[0], bool):
+            if len(value_list) == 1:
+                # If only 1 bool value is given (True/False) set the where to the value. Else skip.
+                where[key] = value_list[0]
+            continue  # Skip adding as both True/False must be there
         where[key] = list(value)
     query = {
         'where': where,
-        **query_info['range']
+        **query_info['range'],
+        'useFieldAlias': True,
+        'remapSchemaToAlias': True
     }
     try:
         if query_info['realTime'] and not query_info['range']:
@@ -92,7 +102,7 @@ def fetch_query(query_info: Dict):
     if df.empty:
         return df
     df.set_index('date' if 'date' in df.columns else 'time', inplace=True)
-    df.index = to_datetime(df.index)
+    df.index = to_datetime(df.index).tz_localize(None)
     return df
 
 
