@@ -15,7 +15,8 @@ under the License.
 """
 
 import copy
-from typing import List, Optional
+import uuid
+from typing import List, Optional, Dict, Set, Tuple
 
 from pandas import Series
 
@@ -43,6 +44,7 @@ class DataCell:
                  row_group: str = None):
         # Cell starts with root processor
         # Deep copies so the processor and children are unique objects
+        self.cell_id = str(uuid.uuid4())
         self.processor: BaseProcessor = copy.deepcopy(processor)
         self.entity: Entity = entity
         self.name: str = name
@@ -59,7 +61,7 @@ class DataCell:
         # Store the cell data queries
         self.data_queries: List[DataQueryInfo] = []
 
-    def build_cell_graph(self, all_queries: List[DataQueryInfo]) -> None:
+    def build_cell_graph(self, all_queries: List[DataQueryInfo], rdate_entity_map: Dict[str, Set[Tuple]]) -> None:
         """ Generate and store the cell graph and data queries
 
             This can be modified to return the data queries rather than store on the cell
@@ -71,6 +73,7 @@ class DataCell:
             self.processor.build_graph(self.entity,
                                        self,
                                        cell_queries,
+                                       rdate_entity_map,
                                        self.dimension_overrides)
 
             self.data_queries = cell_queries
