@@ -41,7 +41,8 @@ class VolatilityProcessor(BaseProcessor):
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
                  w: Union[Window, int] = Window(None, 0),
-                 returns_type: Returns = Returns.SIMPLE):
+                 returns_type: Returns = Returns.SIMPLE,
+                 **kwargs):
         """ VolatilityProcessor
 
         :param a: DataCoordinate or BaseProcessor for the series to apply the volatility timeseries function
@@ -52,7 +53,7 @@ class VolatilityProcessor(BaseProcessor):
               Window size defaults to length of series.
         :param returns_type: returns type: simple, logarithmic or absolute
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinate
         self.children['a'] = a
 
@@ -73,6 +74,8 @@ class VolatilityProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, 'Processor does not have data')
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -86,7 +89,8 @@ class SharpeRatioProcessor(BaseProcessor):
                  end: Optional[DateOrDatetimeOrRDate] = None,
                  currency: Currency,
                  w: Union[Window, int] = None,
-                 curve_type: CurveType = CurveType.PRICES):
+                 curve_type: CurveType = CurveType.PRICES,
+                 **kwargs):
         """ SharpeRatioProcessor
 
         :param a: DataCoordinate or BaseProcessor for the series of prices or excess returns
@@ -97,7 +101,7 @@ class SharpeRatioProcessor(BaseProcessor):
         :param start: start date or time used in the underlying data query
         :param end: end date or time used in the underlying data query
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinates
         self.children['a'] = a
         # datetime
@@ -135,6 +139,8 @@ class SharpeRatioProcessor(BaseProcessor):
                 ratio = get_ratio_pure(excess_returns, self.w)
                 self.value = ProcessorResult(True, ratio)
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -148,7 +154,8 @@ class CorrelationProcessor(BaseProcessor):
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
                  w: Union[Window, int] = Window(None, 0),
-                 type_: SeriesType = SeriesType.PRICES):
+                 type_: SeriesType = SeriesType.PRICES,
+                 **kwargs):
         """ CorrelationProcessor
 
         :param a: DataCoordinate or BaseProcessor for the series
@@ -160,7 +167,7 @@ class CorrelationProcessor(BaseProcessor):
                 Window size defaults to length of series.
         :param type_: type of both input series: prices or returns
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinate
         self.children['a'] = a
 
@@ -194,6 +201,8 @@ class CorrelationProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "Processor does not have A and Benchmark data yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -204,7 +213,8 @@ class ChangeProcessor(BaseProcessor):
                  a: DataCoordinateOrProcessor,
                  *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
-                 end: Optional[DateOrDatetimeOrRDate] = None):
+                 end: Optional[DateOrDatetimeOrRDate] = None,
+                 **kwargs):
 
         """ ChangeProcessor computes the change of a series
 
@@ -212,7 +222,7 @@ class ChangeProcessor(BaseProcessor):
         :param start: start date or time used in the underlying data query
         :param end: end date or time used in the underlying data query
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinate
         self.children['a'] = a
 
@@ -220,13 +230,15 @@ class ChangeProcessor(BaseProcessor):
         self.start = start
         self.end = end
 
-    def process(self) -> None:
+    def process(self):
         a_data = self.children_data.get('a')
         if isinstance(a_data, ProcessorResult):
             if a_data.success:
                 value = change(a_data.data)
                 self.value = ProcessorResult(True, value)
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -239,7 +251,8 @@ class ReturnsProcessor(BaseProcessor):
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
                  observations: Optional[int] = None,
-                 type_: Returns = Returns.SIMPLE):
+                 type_: Returns = Returns.SIMPLE,
+                 **kwargs):
 
         """ ReturnsProcessor computes the returns of a series
 
@@ -249,7 +262,7 @@ class ReturnsProcessor(BaseProcessor):
         :param observations: number of observations, defaults to the return of the entire series as a single value
         :param type_: simple, logarithmic or absolute
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinate
         self.children['a'] = a
 
@@ -260,7 +273,7 @@ class ReturnsProcessor(BaseProcessor):
         self.observations = observations
         self.type_ = type_
 
-    def process(self) -> None:
+    def process(self):
         a_data = self.children_data.get('a')
         if isinstance(a_data, ProcessorResult):
             if a_data.success:
@@ -274,6 +287,8 @@ class ReturnsProcessor(BaseProcessor):
                     value = returns(a_data.data, self.observations, self.type_)
                     self.value = ProcessorResult(True, value)
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -285,7 +300,8 @@ class BetaProcessor(BaseProcessor):
                  *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 w: Union[Window, int] = Window(None, 0)):
+                 w: Union[Window, int] = Window(None, 0),
+                 **kwargs):
         """ BetaProcessor
 
         :param a: DataCoordinate or BaseProcessor for the first series
@@ -302,7 +318,7 @@ class BetaProcessor(BaseProcessor):
         If window is not provided, computes beta over the full series
 
         """
-        super().__init__()
+        super().__init__(**kwargs)
         self.children['a'] = a
         self.children['b'] = b
 
@@ -329,5 +345,7 @@ class BetaProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "BetaProcessor does not have 'a' series yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
