@@ -30,7 +30,8 @@ class PercentilesProcessor(BaseProcessor):
                  b: Optional[DataCoordinateOrProcessor] = None,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 w: Union[Window, int] = Window(None, 0)):
+                 w: Union[Window, int] = Window(None, 0),
+                 **kwargs):
         """ PercentilesProcessor
 
         :param a: DataCoordinate or BaseProcessor for the first series
@@ -41,7 +42,7 @@ class PercentilesProcessor(BaseProcessor):
               and 10 the ramp up value.  If w is a string, it should be a relative date like '1m', '1d', etc.
               Window size defaults to length of series.
         """
-        super().__init__()
+        super().__init__(**kwargs)
         self.children['a'] = a
         self.children['b'] = b
 
@@ -68,6 +69,8 @@ class PercentilesProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "PercentilesProcessor does not have 'a' series yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -79,7 +82,8 @@ class PercentileProcessor(BaseProcessor):
                  n: float,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 w: Union[Window, int] = None):
+                 w: Union[Window, int] = None,
+                 **kwargs):
         """ PercentileProcessor
 
         :param a: DataCoordinate or BaseProcessor for the series
@@ -90,7 +94,7 @@ class PercentileProcessor(BaseProcessor):
               and 10 the ramp up value.  If w is a string, it should be a relative date like '1m', '1d', etc.
               Window size defaults to length of series.
         """
-        super().__init__()
+        super().__init__(**kwargs)
         self.children['a'] = a
         self.n = n
         self.start = start
@@ -114,6 +118,8 @@ class PercentileProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "PercentileProcessor does not have 'a' series yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -124,7 +130,8 @@ class MeanProcessor(BaseProcessor):
                  *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 w: Union[Window, int] = None):
+                 w: Union[Window, int] = None,
+                 **kwargs):
         """ MeanProcessor
 
         :param a: DataCoordinate or BaseProcessor for the series
@@ -143,8 +150,7 @@ class MeanProcessor(BaseProcessor):
         available data, will return mean of available values.
 
         """
-
-        super().__init__()
+        super().__init__(**kwargs)
         self.children['a'] = a
         self.start = start
         self.end = end
@@ -165,6 +171,8 @@ class MeanProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "MeanProcessor does not have 'a' series yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -175,7 +183,8 @@ class SumProcessor(BaseProcessor):
                  *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 w: Union[Window, int] = None):
+                 w: Union[Window, int] = None,
+                 **kwargs):
         """ SumProcessor
 
         :param a: DataCoordinate or BaseProcessor for the series
@@ -194,7 +203,7 @@ class SumProcessor(BaseProcessor):
 
         """
 
-        super().__init__()
+        super().__init__(**kwargs)
         self.children['a'] = a
         self.start = start
         self.end = end
@@ -215,6 +224,8 @@ class SumProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "SumProcessor does not have 'a' series yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -225,7 +236,8 @@ class StdDevProcessor(BaseProcessor):
                  *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 w: Union[Window, int] = Window(None, 0)):
+                 w: Union[Window, int] = Window(None, 0),
+                 **kwargs):
         """ StdDevProcessor
 
         :param a: DataCoordinate or BaseProcessor for the first series
@@ -242,7 +254,7 @@ class StdDevProcessor(BaseProcessor):
 
         If window is not provided, computes standard deviation over the full series
         """
-        super().__init__()
+        super().__init__(**kwargs)
         self.children['a'] = a
 
         self.start = start
@@ -264,6 +276,8 @@ class StdDevProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "StdDevProcessor does not have 'a' series yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -274,7 +288,8 @@ class VarianceProcessor(BaseProcessor):
                  *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 w: Union[Window, int] = Window(None, 0)):
+                 w: Union[Window, int] = Window(None, 0),
+                 **kwargs):
         """ VarianceProcessor
 
         :param a: DataCoordinate or BaseProcessor for the first series
@@ -290,7 +305,7 @@ class VarianceProcessor(BaseProcessor):
         sample variance <https://en.wikipedia.org/wiki/Variance>`_ over a rolling window
         If window is not provided, computes variance over the full series
         """
-        super().__init__()
+        super().__init__(**kwargs)
         self.children['a'] = a
 
         self.start = start
@@ -312,6 +327,8 @@ class VarianceProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "VarianceProcessor does not have 'a' series yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -323,7 +340,8 @@ class CovarianceProcessor(BaseProcessor):
                  *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 w: Union[Window, int] = Window(None, 0)):
+                 w: Union[Window, int] = Window(None, 0),
+                 **kwargs):
         """ CovarianceProcessor
 
         :param a: DataCoordinate or BaseProcessor for the first series
@@ -340,7 +358,7 @@ class CovarianceProcessor(BaseProcessor):
 
         If window is not provided, computes variance over the full series
         """
-        super().__init__()
+        super().__init__(**kwargs)
         self.children['a'] = a
         self.children['b'] = b
 
@@ -367,6 +385,8 @@ class CovarianceProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "CovarianceProcessor does not have 'a' series yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -377,7 +397,8 @@ class ZscoresProcessor(BaseProcessor):
                  *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 w: Union[Window, int] = None):
+                 w: Union[Window, int] = None,
+                 **kwargs):
         """ ZscoresProcessor
 
         :param a: DataCoordinate or BaseProcessor for the series
@@ -398,7 +419,7 @@ class ZscoresProcessor(BaseProcessor):
 
         """
 
-        super().__init__()
+        super().__init__(**kwargs)
         self.children['a'] = a
         self.start = start
         self.end = end
@@ -408,16 +429,14 @@ class ZscoresProcessor(BaseProcessor):
         a_data = self.children_data.get('a')
         if isinstance(a_data, ProcessorResult):
             if a_data.success:
-                series_length = len(a_data.data)
-                window = None
-                if self.w:
-                    window = self.w if self.w <= series_length else series_length
-                result = zscores(a_data.data, w=window)
+                result = zscores(a_data.data, w=Window(None, 0) if self.w is None else self.w)
                 self.value = ProcessorResult(True, result)
             else:
                 self.value = ProcessorResult(False, "ZscoresProcessor does not have 'a' series values yet")
         else:
             self.value = ProcessorResult(False, "ZscoresProcessor does not have 'a' series yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
