@@ -27,15 +27,17 @@ class LastProcessor(BaseProcessor):
 
     def __init__(self,
                  a: DataCoordinateOrProcessor,
+                 *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
-                 end: Optional[DateOrDatetimeOrRDate] = None):
+                 end: Optional[DateOrDatetimeOrRDate] = None,
+                 **kwargs):
         """ LastProcessor returns the last value of the series
 
         :param a: DataCoordinate or BaseProcessor for the first coordinate
         :param start: start date or time used in the underlying data query
         :param end: end date or time used in the underlying data query
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinates
         self.children['a'] = a
 
@@ -43,13 +45,15 @@ class LastProcessor(BaseProcessor):
         self.start = start
         self.end = end
 
-    def process(self) -> None:
+    def process(self):
         """ Calculate the result and store it as the processor value """
         a_data = self.children_data.get('a')
         if isinstance(a_data, ProcessorResult):
             if a_data.success and isinstance(a_data.data, Series):
                 self.value = ProcessorResult(True, pd.Series(a_data.data[-1:]))
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -58,15 +62,17 @@ class MinProcessor(BaseProcessor):
 
     def __init__(self,
                  a: DataCoordinateOrProcessor,
+                 *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
-                 end: Optional[DateOrDatetimeOrRDate] = None):
+                 end: Optional[DateOrDatetimeOrRDate] = None,
+                 **kwargs):
         """ MinProcessor returns the minimum value of the series
 
         :param a: DataCoordinate or BaseProcessor for the coordinate
         :param start: start date or time used in the underlying data query
         :param end: end date or time used in the underlying data query
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinates
         self.children['a'] = a
 
@@ -74,7 +80,7 @@ class MinProcessor(BaseProcessor):
         self.start = start
         self.end = end
 
-    def process(self) -> None:
+    def process(self):
         """ Calculate the result and store it as the processor value """
         a = self.children_data.get('a')
         if isinstance(a, ProcessorResult):
@@ -85,6 +91,8 @@ class MinProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "Processor does not have series yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -93,15 +101,17 @@ class MaxProcessor(BaseProcessor):
 
     def __init__(self,
                  a: DataCoordinateOrProcessor,
+                 *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
-                 end: Optional[DateOrDatetimeOrRDate] = None):
+                 end: Optional[DateOrDatetimeOrRDate] = None,
+                 **kwargs):
         """ MaxProcessor returns the maximum value of the series
 
         :param a: DataCoordinate or BaseProcessor for the coordinate
         :param start: start date or time used in the underlying data query
         :param end: end date or time used in the underlying data query
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinates
         self.children['a'] = a
 
@@ -109,7 +119,7 @@ class MaxProcessor(BaseProcessor):
         self.start = start
         self.end = end
 
-    def process(self) -> None:
+    def process(self):
         """ Calculate the result and store it as the processor value """
         a = self.children_data.get('a')
         if isinstance(a, ProcessorResult):
@@ -120,6 +130,8 @@ class MaxProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "Processor does not have series yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -130,7 +142,8 @@ class AppendProcessor(BaseProcessor):
                  b: DataCoordinateOrProcessor,
                  *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
-                 end: Optional[DateOrDatetimeOrRDate] = None):
+                 end: Optional[DateOrDatetimeOrRDate] = None,
+                 **kwargs):
         """ AppendProcessor appends both a and b data series into one series
 
         :param a: DataCoordinate or BaseProcessor for the first series
@@ -138,7 +151,7 @@ class AppendProcessor(BaseProcessor):
         :param start: start date or time used in the underlying data query
         :param end: end date or time used in the underlying data query
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinates
         self.children['a'] = a
         self.children['b'] = b
@@ -147,7 +160,7 @@ class AppendProcessor(BaseProcessor):
         self.start = start
         self.end = end
 
-    def process(self) -> None:
+    def process(self):
         a_data = self.children_data.get('a')
         b_data = self.children_data.get('b')
         if isinstance(a_data, ProcessorResult) and isinstance(b_data, ProcessorResult):
@@ -159,6 +172,8 @@ class AppendProcessor(BaseProcessor):
         else:
             self.value = ProcessorResult(False, "Processor does not have A and B data yet")
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -166,11 +181,12 @@ class AppendProcessor(BaseProcessor):
 class AdditionProcessor(BaseProcessor):
     def __init__(self,
                  a: DataCoordinateOrProcessor,
-                 *,
                  b: Optional[DataCoordinateOrProcessor] = None,
+                 *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 addend: Optional[float] = None):
+                 addend: Optional[float] = None,
+                 **kwargs):
         """ AdditionProcessor adds two series or an addend to a series
 
 
@@ -180,7 +196,7 @@ class AdditionProcessor(BaseProcessor):
         :param end: end date or time used in the underlying data query
         :param addend: number to add to all values in the series
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinates
         self.children['a'] = a
         self.children['b'] = b
@@ -195,11 +211,11 @@ class AdditionProcessor(BaseProcessor):
         if isinstance(a_data, ProcessorResult):
             if not a_data.success:
                 self.value = a_data
-                return
+                return self.value
             if self.addend:
                 value = a_data.data.add(self.addend)
                 self.value = ProcessorResult(True, value)
-                return
+                return self.value
             b_data = self.children_data.get('b')
             if isinstance(b_data, ProcessorResult):
                 if b_data.success:
@@ -208,6 +224,8 @@ class AdditionProcessor(BaseProcessor):
                 else:
                     self.value = ProcessorResult(True, b_data.data)
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -216,9 +234,11 @@ class SubtractionProcessor(BaseProcessor):
     def __init__(self,
                  a: DataCoordinateOrProcessor,
                  b: Optional[DataCoordinateOrProcessor] = None,
+                 *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 subtrahend: Optional[float] = None):
+                 subtrahend: Optional[float] = None,
+                 **kwargs):
         """ SubtractionProcessor subtract two series or a subtrahend to a series
 
 
@@ -228,7 +248,7 @@ class SubtractionProcessor(BaseProcessor):
         :param end: end date or time used in the underlying data query
         :param subtrahend: number to subtract from all values in the series
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinates
         self.children['a'] = a
         self.children['b'] = b
@@ -243,11 +263,11 @@ class SubtractionProcessor(BaseProcessor):
         if isinstance(a_data, ProcessorResult):
             if not a_data.success:
                 self.value = a_data
-                return
+                return self.value
             if self.subtrahend:
                 value = a_data.data.sub(self.subtrahend)
                 self.value = ProcessorResult(True, value)
-                return
+                return self.value
             b_data = self.children_data.get('b')
             if isinstance(b_data, ProcessorResult):
                 if b_data.success:
@@ -256,6 +276,8 @@ class SubtractionProcessor(BaseProcessor):
                 else:
                     self.value = b_data
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -266,9 +288,11 @@ class MultiplicationProcessor(BaseProcessor):
     def __init__(self,
                  a: DataCoordinateOrProcessor,
                  b: Optional[DataCoordinateOrProcessor] = None,
+                 *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 factor: Optional[float] = None):
+                 factor: Optional[float] = None,
+                 **kwargs):
         """ MultiplicationProcessor multiply two series or a factor to a series
 
 
@@ -278,7 +302,7 @@ class MultiplicationProcessor(BaseProcessor):
         :param end: end date or time used in the underlying data query
         :param factor: number to multiply all values in the series
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinates
         self.children['a'] = a
         self.children['b'] = b
@@ -293,11 +317,11 @@ class MultiplicationProcessor(BaseProcessor):
         if isinstance(a_data, ProcessorResult):
             if not a_data.success:
                 self.value = a_data
-                return
+                return a_data
             if self.factor:
                 value = a_data.data.mul(self.factor)
                 self.value = ProcessorResult(True, value)
-                return
+                return self.value
             b_data = self.children_data.get('b')
             if isinstance(b_data, ProcessorResult):
                 if b_data.success:
@@ -306,6 +330,8 @@ class MultiplicationProcessor(BaseProcessor):
                 else:
                     self.value = b_data
 
+        return self.value
+
     def get_plot_expression(self):
         pass
 
@@ -314,9 +340,11 @@ class DivisionProcessor(BaseProcessor):
     def __init__(self,
                  a: DataCoordinateOrProcessor,
                  b: Optional[DataCoordinateOrProcessor] = None,
+                 *,
                  start: Optional[DateOrDatetimeOrRDate] = None,
                  end: Optional[DateOrDatetimeOrRDate] = None,
-                 dividend: Optional[float] = None):
+                 dividend: Optional[float] = None,
+                 **kwargs):
         """ DivisionProcessor divides two series or divides a dividend to a series
 
 
@@ -326,7 +354,7 @@ class DivisionProcessor(BaseProcessor):
         :param end: end date or time used in the underlying data query
         :param dividend: number to divide all values in the series
         """
-        super().__init__()
+        super().__init__(**kwargs)
         # coordinates
         self.children['a'] = a
         self.children['b'] = b
@@ -341,11 +369,11 @@ class DivisionProcessor(BaseProcessor):
         if isinstance(a_data, ProcessorResult):
             if not a_data.success:
                 self.value = a_data
-                return
+                return self.value
             if self.dividend:
                 value = a_data.data.div(self.dividend)
                 self.value = ProcessorResult(True, value)
-                return
+                return self.value
             b_data = self.children_data.get('b')
             if isinstance(b_data, ProcessorResult):
                 if b_data.success:
@@ -354,5 +382,7 @@ class DivisionProcessor(BaseProcessor):
                 else:
                     self.value = b_data
 
+        return self.value
+
     def get_plot_expression(self):
         pass
