@@ -45,6 +45,7 @@ _logger = logging.getLogger(__name__)
 
 class QueryType(Enum):
     IMPLIED_VOLATILITY = "Implied Volatility"
+    IMPLIED_VOLATILITY_BY_EXPIRATION = "Implied Volatility By Expiration"
     IMPLIED_CORRELATION = "Implied Correlation"
     REALIZED_CORRELATION = "Realized Correlation"
     AVERAGE_IMPLIED_VOLATILITY = "Average Implied Volatility"
@@ -133,6 +134,7 @@ class QueryType(Enum):
     OIS_XCCY_EX_SPIKE = "Ois Xccy Ex Spike"
     USD_OIS = "Usd Ois"
     NON_USD_OIS = "Non Usd Ois"
+    SETTLEMENT_PRICE = "Settlement Price"
 
 
 class GsDataApi(DataApi):
@@ -182,12 +184,16 @@ class GsDataApi(DataApi):
         return results
 
     @classmethod
-    def last_data(cls, query: Union[DataQuery, MDAPIDataQuery], dataset_id: str = None) -> Union[list, tuple]:
+    def last_data(cls, query: Union[DataQuery, MDAPIDataQuery], dataset_id: str = None, timeout: int = None) \
+            -> Union[list, tuple]:
+        kwargs = {}
+        if timeout is not None:
+            kwargs['timeout'] = timeout
         if getattr(query, 'marketDataCoordinates', None):
-            result = GsSession.current._post('/data/coordinates/query/last', payload=query)
+            result = GsSession.current._post('/data/coordinates/query/last', payload=query, **kwargs)
             return result.get('responses', ())
         else:
-            result = GsSession.current._post('/data/{}/last/query'.format(dataset_id), payload=query)
+            result = GsSession.current._post('/data/{}/last/query'.format(dataset_id), payload=query, **kwargs)
             return result.get('data', ())
 
     @classmethod
@@ -496,7 +502,8 @@ class GsDataApi(DataApi):
             as_of: Union[dt.datetime, dt.date] = None,
             vendor: MarketDataVendor = MarketDataVendor.Goldman_Sachs,
             as_dataframe: bool = False,
-            pricing_location: Optional[PricingLocation] = None
+            pricing_location: Optional[PricingLocation] = None,
+            timeout: int = None
     ) -> Union[Dict, pd.DataFrame]:
         """
         Get last value of coordinates data
@@ -506,6 +513,7 @@ class GsDataApi(DataApi):
         :param vendor: data vendor
         :param as_dataframe: whether to return the result as Dataframe
         :param pricing_location: the location where close data has been recorded (not used for real-time query)
+        :param timeout: data query timeout; if timeout is not set then the default timeout is used
         :return: Dataframe or dictionary of the returned data
 
         **Examples**
@@ -522,7 +530,11 @@ class GsDataApi(DataApi):
             pricing_location=pricing_location
         )
 
-        data = cls.last_data(query)
+        kwargs = {}
+        if timeout is not None:
+            kwargs['timeout'] = timeout
+
+        data = cls.last_data(query, **kwargs)
 
         if not as_dataframe:
             ret = {coordinate: None for coordinate in market_data_coordinates}
@@ -534,13 +546,14 @@ class GsDataApi(DataApi):
             return ret
 
         ret = []
+        datetime_field = 'time' if isinstance(as_of, dt.datetime) else 'date'
         for idx, row in enumerate(cls.__normalise_coordinate_data(data)):
             coordinate_as_dict = market_data_coordinates[idx].as_dict(as_camel_case=True)
             try:
                 ret.append(dict(chain(coordinate_as_dict.items(),
-                                      (('value', row[0]['value']), ('time', row[0]['time'])))))
+                                      (('value', row[0]['value']), (datetime_field, row[0][datetime_field])))))
             except IndexError:
-                ret.append(dict(chain(coordinate_as_dict.items(), (('value', None), ('time', None)))))
+                ret.append(dict(chain(coordinate_as_dict.items(), (('value', None), (datetime_field, None)))))
         return cls.__df_from_coordinate_data(ret, use_datetime_index=False)
 
     @classmethod
