@@ -15,13 +15,15 @@ under the License.
 """
 import datetime as dt
 import logging
-from typing import Tuple, Union
+from typing import Tuple, Union, List
 
+from gs_quant.common import PositionType
 from gs_quant.instrument import Instrument
 from gs_quant.session import GsSession
 from gs_quant.target.common import RiskRequest
 from gs_quant.target.portfolios import Portfolio, Position, PositionSet
 from gs_quant.target.reports import Report
+from gs_quant.target.risk_models import Term
 
 _logger = logging.getLogger(__name__)
 
@@ -30,8 +32,16 @@ class GsPortfolioApi:
     """GS Asset API client implementation"""
 
     @classmethod
-    def get_portfolios(cls, limit: int = 100) -> Tuple[Portfolio, ...]:
-        return GsSession.current._get('/portfolios?limit={limit}'.format(limit=limit), cls=Portfolio)['results']
+    def get_portfolios(cls,
+                       portfolio_ids: List[str] = None,
+                       portfolio_names: List[str] = None,
+                       limit: int = 100) -> Tuple[Portfolio, ...]:
+        url = '/portfolios?'
+        if portfolio_ids:
+            url += f'&id={"&id=".join(portfolio_ids)}'
+        if portfolio_names:
+            url += f'&name={"&name=".join(portfolio_names)}'
+        return GsSession.current._get(f'{url}&limit={limit}', cls=Portfolio)['results']
 
     @classmethod
     def get_portfolio(cls, portfolio_id: str) -> Portfolio:
@@ -81,7 +91,7 @@ class GsPortfolioApi:
         url = '/portfolios/{id}/positions/{date}?type={ptype}'.format(
             id=portfolio_id, date=position_date.isoformat(), ptype=position_type)
         position_sets = GsSession.current._get(url, cls=PositionSet)['results']
-        return position_sets[0] if len(position_sets) > 0 else PositionSet()
+        return position_sets[0] if len(position_sets) > 0 else None
 
     @classmethod
     def get_instruments_by_position_type(cls, positions_type: str,
@@ -112,7 +122,7 @@ class GsPortfolioApi:
         if isinstance(results, dict) and 'positions' in results:
             results['positions'] = tuple(Position.from_dict(p) for p in results['positions'])
 
-        return results
+        return PositionSet.from_dict(results)
 
     @classmethod
     def get_instruments_by_workflow_id(cls, workflow_id: str,
@@ -139,9 +149,27 @@ class GsPortfolioApi:
         return tuple(dt.datetime.strptime(d, '%Y-%m-%d').date() for d in position_dates)
 
     @classmethod
-    def update_positions(cls, portfolio_id: str, position_sets: Tuple[PositionSet, ...]) -> float:
+    def update_positions(cls, portfolio_id: str, position_sets: List[PositionSet]) -> float:
         return GsSession.current._put('/portfolios/{id}/positions'.format(id=portfolio_id), position_sets)
 
+    @classmethod
+    def get_positions_data(cls,
+                           portfolio_id: str,
+                           start_date: dt.date,
+                           end_date: dt.date,
+                           fields: List[str] = None,
+                           position_type: PositionType = None) -> List[dict]:
+        start_date_str = start_date.isoformat()
+        end_date_str = end_date.isoformat()
+        url = f'/portfolios/{portfolio_id}/positions/data?startDate={start_date_str}&endDate={end_date_str}'
+        if fields is not None:
+            url += '&fields='.join([''] + fields)
+
+        if position_type is not None:
+            url += '&type=' + position_type.value
+
+        return GsSession.current._get(url)['results']
+
     @classmethod
     def update_quote(cls, portfolio_id: str, request: RiskRequest):
         return GsSession.current._put('/risk-internal/quote/save/{id}'.format(id=portfolio_id), request)
@@ -150,16 +178,24 @@ class GsPortfolioApi:
     def save_quote(cls, request: RiskRequest) -> str:
         return GsSession.current._post('/risk-internal/quote/save', request)['results']
 
-    # manage portfolio reports
+    @classmethod
+    def get_risk_models_by_coverage(cls, portfolio_id: str, term: Term = Term.Medium):
+        return GsSession.current._get(f'/portfolios/{portfolio_id}/models?sortByTerm={term.value}')['results']
 
     @classmethod
     def get_reports(cls, portfolio_id: str) -> Tuple[Report, ...]:
         return GsSession.current._get('/portfolios/{id}/reports'.format(id=portfolio_id), cls=Report)['results']
 
     @classmethod
-    def schedule_reports(cls, portfolio_id: str, start_date: dt.date, end_date: dt.date = None) -> dict:
+    def schedule_reports(cls,
+                         portfolio_id: str,
+                         start_date: dt.date,
+                         end_date: dt.date = None,
+                         backcast: bool = False) -> dict:
         if end_date is None:
             payload = {'startDate': start_date.isoformat()}
         else:
             payload = {'startDate': start_date.isoformat(), 'endDate': end_date.isoformat()}
+        if backcast:
+            payload['parameters'] = {'backcast': True}
         return GsSession.current._post('/portfolios/{id}/schedule'.format(id=portfolio_id), payload)
