@@ -28,14 +28,15 @@ import numpy as np
 import datetime as dt
 
 
-class BackTest(object):
+class BackTest:
     def __init__(self, strategy, states, risks):
         self._portfolio_dict = defaultdict(Portfolio)  # portfolio by state
         self._cash_dict = defaultdict(float)  # cash by state
         self._scaling_portfolios = defaultdict(list)  # list of ScalingPortfolio
+        self._cash_payments = defaultdict(list)  # list of cash payments (entry, unwind)
         self._strategy = deepcopy(strategy)  # the strategy definition
         self._states = states  # list of states
-        self._results = defaultdict()
+        self._results = defaultdict(list)
         self._risks = tuple(risks)  # list of risks to calculate
         self._calc_calls = 0
         self._calculations = 0
@@ -60,6 +61,14 @@ class BackTest(object):
     def scaling_portfolios(self, scaling_portfolios):
         self._scaling_portfolios = scaling_portfolios
 
+    @property
+    def cash_payments(self):
+        return self._cash_payments
+
+    @cash_payments.setter
+    def cash_payments(self, cash_payments):
+        self._cash_payments = cash_payments
+
     @property
     def states(self):
         return self._states
@@ -68,12 +77,15 @@ class BackTest(object):
     def results(self):
         return self._results
 
+    def set_results(self, date, results):
+        self._results[date] = results
+
     @property
     def risks(self):
         return self._risks
 
     def add_results(self, date, results):
-        if date in self._results:
+        if date in self._results and len(self._results[date]):
             self._results[date] += results
         else:
             self._results[date] = results
@@ -102,17 +114,25 @@ class BackTest(object):
         return summary.fillna(0)
 
 
-class ScalingPortfolio(object):
-    def __init__(self, trade, dates, risk, csa_term=None, unwind=False):
+class ScalingPortfolio:
+    def __init__(self, trade, dates, risk, csa_term=None, scaling_parameter='notional_amount'):
         self.trade = trade
         self.dates = dates
         self.risk = risk
         self.csa_term = csa_term
+        self.scaling_parameter = scaling_parameter
         self.results = None
-        self.unwind = unwind
 
 
-class PredefinedAssetBacktest(object):
+class CashPayment:
+    def __init__(self, trade, effective_date=None, scale_date=None, direction=1):
+        self.trade = trade
+        self.effective_date = effective_date
+        self.scale_date = scale_date
+        self.direction = direction
+
+
+class PredefinedAssetBacktest:
     """
     :param data_handler: holds all the data required to run the backtest
     :param performance: backtest values
