@@ -43,9 +43,16 @@ class OrderBase(metaclass=ABCMeta):
     def execution_end_time(self) -> dt.datetime:
         raise RuntimeError('The method execution_end_time is not implemented on OrderBase')
 
-    def execution_price(self, data_handler: DataHandler) -> float:
+    def _execution_price(self, data_handler: DataHandler) -> float:
         raise RuntimeError('The method execution_price is not implemented on OrderBase')
 
+    def execution_price(self, data_handler: DataHandler) -> float:
+        price = self._execution_price(data_handler)
+        if np.isnan(price):
+            raise RuntimeError('can not compute the execution price')
+        else:
+            return price
+
     def execution_quantity(self, data_handler: DataHandler) -> float:
         raise RuntimeError('The method execution_price is not implemented on OrderBase')
 
@@ -80,7 +87,7 @@ class OrderTWAP(OrderBase):
     def execution_end_time(self) -> dt.datetime:
         return self.window.end
 
-    def execution_price(self, data_handler: DataHandler) -> float:
+    def _execution_price(self, data_handler: DataHandler) -> float:
         fixings = data_handler.get_data_range(self.window.start, self.window.end,
                                               self.instrument, ValuationFixingType.PRICE)
         return np.mean(fixings)
@@ -105,7 +112,7 @@ class OrderMarketOnClose(OrderBase):
     def execution_end_time(self) -> dt.datetime:
         return dt.datetime.combine(self.execution_date, dt.time(23, 0, 0))
 
-    def execution_price(self, data_handler: DataHandler) -> float:
+    def _execution_price(self, data_handler: DataHandler) -> float:
         return data_handler.get_data(self.execution_date, self.instrument, ValuationFixingType.PRICE)
 
     def execution_quantity(self, data_handler: DataHandler) -> float:
@@ -127,7 +134,7 @@ class OrderCost(OrderBase):
     def execution_end_time(self) -> dt.datetime:
         return self.execution_time
 
-    def execution_price(self, data_handler: DataHandler) -> float:
+    def _execution_price(self, data_handler: DataHandler) -> float:
         return 0
 
     def execution_quantity(self, data_handler: DataHandler) -> float:
@@ -157,7 +164,7 @@ class OrderAtMarket(OrderBase):
     def execution_end_time(self) -> dt.datetime:
         return self.execution_datetime
 
-    def execution_price(self, data_handler: DataHandler) -> float:
+    def _execution_price(self, data_handler: DataHandler) -> float:
         return data_handler.get_data(self.execution_datetime, self.instrument, ValuationFixingType.PRICE)
 
     def execution_quantity(self, data_handler: DataHandler) -> float:
@@ -174,19 +181,20 @@ class OrderTwapBTIC(OrderTWAP):
                  generation_time: dt.datetime,
                  source: str,
                  window: TimeWindow,
-                 btic_instrument: Instrument):
+                 btic_instrument: Instrument,
+                 future_underlying):
         super().__init__(instrument, quantity, generation_time, source, window)
         """
-        Create a TWAP order
-        :param window: TWAP window
+        Create a BTIC TWAP order: an order for a future executed at underlying spot + BTIC TWAP
         """
         self.btic_instrument = btic_instrument
+        self.future_underlying = future_underlying
 
-    def execution_price(self, data_handler: DataHandler) -> float:
+    def _execution_price(self, data_handler: DataHandler) -> float:
         btic_fixings = data_handler.get_data_range(self.window.start, self.window.end,
                                                    self.btic_instrument, ValuationFixingType.PRICE)
         btic_twap = np.mean(btic_fixings)
-        close = data_handler.get_data(self.window.end.date(), self.instrument, ValuationFixingType.PRICE)
+        close = data_handler.get_data(self.window.end.date(), self.future_underlying)
 
         return close + btic_twap
 
