@@ -20,12 +20,14 @@ import time
 from abc import ABCMeta, abstractmethod
 from dataclasses import dataclass
 from enum import Enum
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Optional, Tuple, Union
 
+import pandas as pd
 from pydash import get
 
 from gs_quant.api.gs.assets import GsAssetApi
 from gs_quant.api.gs.data import GsDataApi
+from gs_quant.api.gs.portfolios import GsPortfolioApi
 from gs_quant.api.gs.reports import GsReportApi
 from gs_quant.common import DateLimit, PositionType
 from gs_quant.data import DataCoordinate, DataFrequency, DataMeasure
@@ -33,8 +35,9 @@ from gs_quant.data.coordinate import DataDimensions
 from gs_quant.entities.entitlements import Entitlements
 from gs_quant.errors import MqError
 from gs_quant.markets.position_set import PositionSet
+from gs_quant.markets.report import PerformanceReport, FactorRiskReport, Report
 from gs_quant.session import GsSession
-from gs_quant.target.reports import ReportStatus
+from gs_quant.target.reports import ReportStatus, ReportType
 
 _logger = logging.getLogger(__name__)
 
@@ -67,7 +70,9 @@ class Entity(metaclass=ABCMeta):
         EntityType.ASSET: 'assets',
         EntityType.COUNTRY: 'countries',
         EntityType.SUBDIVISION: 'countries/subdivisions',
-        EntityType.KPI: 'kpis'
+        EntityType.KPI: 'kpis',
+        EntityType.PORTFOLIO: 'portfolios',
+        EntityType.RISK_MODEL: 'risk/models'
     }
 
     def __init__(self,
@@ -92,7 +97,7 @@ class Entity(metaclass=ABCMeta):
     def get(cls,
             id_value: str,
             id_type: Union[EntityIdentifier, str],
-            entity_type: Optional[Union[EntityType, str]] = None) -> Optional['Entity']:
+            entity_type: Optional[Union[EntityType, str]] = None):
         id_type = id_type.value if isinstance(id_type, Enum) else id_type
 
         if entity_type is None:
@@ -125,6 +130,8 @@ class Entity(metaclass=ABCMeta):
             return KPI(id_, entity=entity)
         if entity_type == EntityType.SUBDIVISION:
             return Subdivision(id_, entity=entity)
+        if entity_type == EntityType.RISK_MODEL:
+            return RiskModelEntity(id_, entity=entity)
 
     def get_marquee_id(self) -> str:
         return self.__id
@@ -275,6 +282,43 @@ class KPI(Entity):
         return get(self.get_entity(), 'subCategory')
 
 
+class RiskModelEntity(Entity):
+    class Identifier(EntityIdentifier):
+        MARQUEE_ID = "MQID"
+        name = 'name'
+
+    def __init__(self,
+                 id_: str,
+                 entity: Optional[Dict] = None):
+        super().__init__(id_, EntityType.RISK_MODEL, entity)
+
+    @property
+    def data_dimension(self) -> str:
+        return 'riskModel'
+
+    @classmethod
+    def entity_type(cls) -> EntityType:
+        return EntityType.RISK_MODEL
+
+    @classmethod
+    def get_by_identifier(cls,
+                          id_value: str,
+                          id_type: Identifier) -> Optional['Entity']:
+        super().get(id_value, id_type)
+
+    def get_name(self) -> Optional[str]:
+        return get(self.get_entity(), 'name')
+
+    def get_coverage(self) -> Optional[str]:
+        return get(self.get_entity(), 'coverage')
+
+    def get_term(self) -> Optional[str]:
+        return get(self.get_entity(), 'term')
+
+    def get_vendor(self) -> Optional[str]:
+        return get(self.get_entity(), 'vendor')
+
+
 class PositionedEntity(metaclass=ABCMeta):
     def __init__(self, id_: str, entity_type: EntityType):
         self.__id: str = id_
@@ -293,6 +337,10 @@ class PositionedEntity(metaclass=ABCMeta):
         if self.positioned_entity_type == EntityType.ASSET:
             response = GsAssetApi.get_latest_positions(self.id, position_type)
             return PositionSet.from_target(response)
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            response = GsPortfolioApi.get_latest_positions(portfolio_id=self.id,
+                                                           position_type=position_type.value)
+            return PositionSet.from_target(response)
         raise NotImplementedError
 
     def get_position_set_for_date(self,
@@ -301,6 +349,11 @@ class PositionedEntity(metaclass=ABCMeta):
         if self.positioned_entity_type == EntityType.ASSET:
             response = GsAssetApi.get_asset_positions_for_date(self.id, date, position_type)[0]
             return PositionSet.from_target(response)
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            response = GsPortfolioApi.get_positions_for_date(portfolio_id=self.id,
+                                                             position_date=date,
+                                                             position_type=position_type.value)
+            return PositionSet.from_target(response) if response else None
         raise NotImplementedError
 
     def get_position_sets(self,
@@ -310,8 +363,35 @@ class PositionedEntity(metaclass=ABCMeta):
         if self.positioned_entity_type == EntityType.ASSET:
             response = GsAssetApi.get_asset_positions_for_dates(self.id, start, end, position_type)
             return [PositionSet.from_target(position_set) for position_set in response]
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            response = GsPortfolioApi.get_positions(portfolio_id=self.id,
+                                                    start_date=start,
+                                                    end_date=end)
+            return [PositionSet.from_target(position_set) for position_set in response]
         raise NotImplementedError
 
+    def update_positions(self,
+                         position_sets: List[PositionSet],
+                         schedule_reports: bool = True):
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            if not position_sets:
+                return
+            existing_positions_dates = self.get_position_dates()
+            new_position_dates = [p.date for p in position_sets] if position_sets else []
+            reports = [r.latest_end_date for r in self.get_reports() if r.latest_end_date]
+            latest_date_covered_by_reports = min(reports) if reports else None
+            latest_position_date_in_reports = max([d for d in existing_positions_dates
+                                                   if d <= latest_date_covered_by_reports]) \
+                if latest_date_covered_by_reports else min(new_position_dates)
+            start_date = min(latest_position_date_in_reports, min(new_position_dates))
+            end_date = max(new_position_dates)
+            GsPortfolioApi.update_positions(portfolio_id=self.id, position_sets=[p.to_target() for p in position_sets])
+            if schedule_reports:
+                self._schedule_reports(start_date=start_date,
+                                       end_date=end_date)
+        else:
+            raise NotImplementedError
+
     def get_positions_data(self,
                            start: dt.date = DateLimit.LOW_LIMIT.value,
                            end: dt.date = dt.date.today(),
@@ -319,6 +399,75 @@ class PositionedEntity(metaclass=ABCMeta):
                            position_type: PositionType = PositionType.CLOSE) -> List[Dict]:
         if self.positioned_entity_type == EntityType.ASSET:
             return GsAssetApi.get_asset_positions_data(self.id, start, end, fields, position_type)
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            return GsPortfolioApi.get_positions_data(self.id, start, end, fields, position_type)
+        raise NotImplementedError
+
+    def get_position_dates(self) -> Tuple[dt.date, ...]:
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            return GsPortfolioApi.get_position_dates(portfolio_id=self.id)
+        if self.positioned_entity_type == EntityType.ASSET:
+            return GsAssetApi.get_position_dates(asset_id=self.id)
+        raise NotImplementedError
+
+    def get_reports(self) -> List[Report]:
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            reports_as_target = GsPortfolioApi.get_reports(portfolio_id=self.id)
+        elif self.positioned_entity_type == EntityType.ASSET:
+            reports_as_target = GsAssetApi.get_reports(asset_id=self.id)
+        else:
+            raise NotImplementedError
+        report_objects = []
+        for report in reports_as_target:
+            if report.type == ReportType.Portfolio_Performance_Analytics:
+                report_objects.append(PerformanceReport.from_target(report))
+            elif report.type in [ReportType.Portfolio_Factor_Risk, ReportType.Asset_Factor_Risk]:
+                report_objects.append(FactorRiskReport.from_target(report))
+            else:
+                report_objects.append(Report.from_target(report))
+        return report_objects
+
+    def get_status_of_reports(self) -> pd.DataFrame:
+        reports = self.get_reports()
+        reports_dict = {
+            'Name': [r.name for r in reports],
+            'ID': [r.id for r in reports],
+            'Latest Execution Time': [r.latest_execution_time for r in reports],
+            'Latest End Date': [r.latest_end_date for r in reports],
+            "Status": [r.status for r in reports],
+            'Percentage Complete': [r.percentage_complete for r in reports]
+        }
+
+        return pd.DataFrame.from_dict(reports_dict)
+
+    def get_factor_risk_report(self,
+                               risk_model_id: str = None,
+                               fx_hedged: bool = None) -> FactorRiskReport:
+        if self.positioned_entity_type in [EntityType.PORTFOLIO, EntityType.ASSET]:
+            position_source_type = self.positioned_entity_type.value.capitalize()
+            reports = GsReportApi.get_reports(limit=100,
+                                              position_source_type=position_source_type,
+                                              position_source_id=self.id,
+                                              report_type=f'{position_source_type} Factor Risk')
+            if fx_hedged:
+                reports = [report for report in reports if report.parameters.fx_hedged == fx_hedged]
+            if risk_model_id:
+                reports = [report for report in reports if report.parameters.risk_model == risk_model_id]
+            if len(reports) > 1:
+                raise MqError(f'This {position_source_type} has more than one factor risk report that matches '
+                              'your parameters. Please specify the risk model ID and fxHedged value in the '
+                              'function parameters.')
+            if len(reports) == 0:
+                raise MqError(f'This {position_source_type} has no factor risk reports that match your parameters.')
+            return FactorRiskReport.from_target(reports[0])
+        raise NotImplementedError
+
+    def create_report(self, report: Report):
+        if self.positioned_entity_type == EntityType.PORTFOLIO:
+            report.set_position_source(self.id)
+            report.save()
+            self._schedule_first_reports([pos_set.date for pos_set in self.get_position_sets()])
+            return report
         raise NotImplementedError
 
     def poll_report(self, report_id: str, timeout: int = 600, step: int = 30) -> ReportStatus:
@@ -329,8 +478,8 @@ class PositionedEntity(metaclass=ABCMeta):
 
         while poll and dt.datetime.now() <= end:
             try:
-                status = GsReportApi.get_report(report_id).status
-                if status not in set([ReportStatus.error, ReportStatus.cancelled, ReportStatus.done]):
+                status = Report.get(report_id).status
+                if status not in {ReportStatus.error, ReportStatus.cancelled, ReportStatus.done}:
                     _logger.info(f'Report is {status} as of {dt.datetime.now().isoformat()}')
                     time.sleep(step)
                 else:
