@@ -32,6 +32,7 @@ from gs_quant.api.gs.reports import GsReportApi
 from gs_quant.api.gs.users import GsUsersApi
 from gs_quant.common import DateLimit, PositionType
 from gs_quant.entities.entity import EntityType, PositionedEntity
+from gs_quant.entities.entitlements import Entitlements as BasketEntitlements
 from gs_quant.errors import MqError, MqValueError
 from gs_quant.json_encoder import JSONEncoder
 from gs_quant.markets.indices_utils import *
@@ -55,11 +56,14 @@ class ErrorMessage(Enum):
     UNMODIFIABLE = 'This property can not be modified since the basket has already been created'
 
 
-def _error(*error_msgs):
+def _validate(*error_msgs):
+    """ Confirms initialization is complete and checks for errors before calling function """
     def _outer(fn):
         @wraps(fn)
         def _inner(self, *args, **kwargs):
-            if has(self, '_Basket__error_messages'):
+            if has(self, '_Basket__error_messages') and self._Basket__error_messages is not None:
+                if len(self._Basket__error_messages) < 1:
+                    self._Basket__finish_initialization()
                 for error_msg in error_msgs:
                     if error_msg in self._Basket__error_messages:
                         raise MqError(error_msg.value)
@@ -72,28 +76,48 @@ class Basket(Asset, PositionedEntity):
     """
     Basket which tracks an evolving portfolio of securities, and can be traded through cash or derivatives markets
     """
-    def __init__(self, identifier: str = None, gs_asset: GsAsset = None, **kwargs):
-        user_tokens = get(GsUsersApi.get_current_user_info(), 'tokens', [])
-        user_is_internal = 'internal' in user_tokens
-        if identifier:
-            gs_asset = self.__get_gs_asset(identifier)
+    def __init__(self, gs_asset: GsAsset = None, **kwargs):
+        self.__error_messages = None
         if gs_asset:
             if gs_asset.type.value not in BasketType.to_list():
                 raise MqValueError(f'Failed to initialize. Asset {gs_asset.id} is not a basket')
             self.__id = gs_asset.id
+            self.__initial_entitlements = gs_asset.entitlements
             asset_entity: Dict = json.loads(json.dumps(gs_asset.as_dict(), cls=JSONEncoder))
             Asset.__init__(self, gs_asset.id, gs_asset.asset_class, gs_asset.name,
                            exchange=gs_asset.exchange, currency=gs_asset.currency, entity=asset_entity)
             PositionedEntity.__init__(self, gs_asset.id, EntityType.ASSET)
-            user_is_admin = any(token in user_tokens for token in get(gs_asset.entitlements, 'admin', []))
             self.__populate_current_attributes_for_existing_basket(gs_asset)
-            self.__set_error_messages(user_is_admin, user_is_internal, True)
-            self.__populate_api_attrs = True
         else:
-            self.__set_error_messages(True, user_is_internal, False)
             self.__populate_default_attributes_for_new_basket(**kwargs)
-            self.__populate_api_attrs = False
+        self.__error_messages = set([])
+        if get(kwargs, '_finish_init', False):
+            self.__finish_initialization()
 
+    @classmethod
+    def get(cls, identifier: str):
+        """
+        Fetch an existing basket
+
+        :param identifier: Any common identifier for a basket (ric, ticker, etc.)
+        :return: Basket object
+
+        **Usage**
+
+        Get existing basket instance
+
+        **Examples**
+
+        Get basket details:
+
+        >>> from gs_quant.markets.baskets import Basket
+        >>>
+        >>> basket = Basket.get("GSMBXXXX")
+        """
+        gs_asset = cls.__get_gs_asset(identifier)
+        return cls(gs_asset=gs_asset, _finish_init=True)
+
+    @_validate()
     def get_details(self) -> pd.DataFrame:
         """
         Get basket details
@@ -110,7 +134,7 @@ class Basket(Asset, PositionedEntity):
 
         >>> from gs_quant.markets.baskets import Basket
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.get_details()
         """
         props = list(CustomBasketsPricingParameters.properties().union(PublishParameters.properties(),
@@ -149,10 +173,10 @@ class Basket(Asset, PositionedEntity):
         response = GsIndexApi.create(create_inputs)
         gs_asset = GsAssetApi.get_asset(response.asset_id)
         self.__latest_create_report = GsReportApi.get_report(response.report_id)
-        self.__init__(gs_asset=gs_asset)
+        self.__init__(gs_asset=gs_asset, _finish_init=True)
         return response.as_dict()
 
-    @_error(ErrorMessage.UNINITIALIZED)
+    @_validate(ErrorMessage.UNINITIALIZED)
     def clone(self):
         """
         Retrieve a clone of an existing basket
@@ -169,18 +193,17 @@ class Basket(Asset, PositionedEntity):
 
         >>> from gs_quant.markets.baskets import Basket
         >>>
-        >>> parent_basket = Basket("GSMBXXXX")
+        >>> parent_basket = Basket.get("GSMBXXXX")
         >>> clone = parent_basket.clone()
 
         **See also**
 
         :func:`create`
         """
-        self.__finish_populating_attributes_for_existing_basket()
         position_set = deepcopy(self.position_set)
         return Basket(position_set=position_set, clone_parent_id=self.id, parent_basket=self.ticker)
 
-    @_error(ErrorMessage.UNINITIALIZED, ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.UNINITIALIZED, ErrorMessage.NON_ADMIN)
     def update(self) -> Dict:
         """
         Update your custom basket
@@ -196,9 +219,13 @@ class Basket(Asset, PositionedEntity):
         :func:`get_details` :func:`poll_status` :func:`create`
 
         """
-        self.__finish_populating_attributes_for_existing_basket()
         edit_inputs, rebal_inputs = self.__get_updates()
+        entitlements = self.__entitlements.to_target()
+        if not entitlements == self.__initial_entitlements:
+            response = GsAssetApi.update_asset_entitlements(self.id, entitlements)
         if edit_inputs is None and rebal_inputs is None:
+            if response:
+                return response.as_dict()
             raise MqValueError('Update failed: Nothing on the basket was changed')
         elif edit_inputs is not None and rebal_inputs is None:
             response = GsIndexApi.edit(self.id, edit_inputs)
@@ -208,11 +235,10 @@ class Basket(Asset, PositionedEntity):
             response = self.__edit_and_rebalance(edit_inputs, rebal_inputs)
         gs_asset = GsAssetApi.get_asset(self.id)
         self.__latest_create_report = GsReportApi.get_report(response.report_id)
-        self.__error_messages.remove(ErrorMessage.UNMODIFIABLE)
-        self.__init__(gs_asset=gs_asset)
+        self.__init__(gs_asset=gs_asset, _finish_init=True)
         return response.as_dict()
 
-    @_error(ErrorMessage.UNINITIALIZED, ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.UNINITIALIZED, ErrorMessage.NON_ADMIN)
     def upload_position_history(self, position_sets: List[PositionSet]) -> Dict:
         """
         Upload basket composition history
@@ -235,7 +261,7 @@ class Basket(Asset, PositionedEntity):
         >>> first_position_set = PositionSet.from_list(['BBID1', 'BBID2'], date(2020, 1, 1))
         >>> second_position_set = PositionSet.from_list(['BBID1','BBID2', 'BBID3'], date(2021, 1, 1))
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.upload_position_history([first_position_set, second_position_set])
 
         **See also**
@@ -251,7 +277,7 @@ class Basket(Asset, PositionedEntity):
         response = GsIndexApi.backcast(CustomBasketsBackcastInputs(tuple(historical_position_sets)))
         return response.as_dict()
 
-    @_error(ErrorMessage.UNINITIALIZED)
+    @_validate(ErrorMessage.UNINITIALIZED)
     def poll_status(self, timeout: int = 600, step: int = 30) -> ReportStatus:
         """
         Polls the status of the basket's most recent create/edit/rebalance report
@@ -270,7 +296,7 @@ class Basket(Asset, PositionedEntity):
 
         >>> from gs_quant.markets.baskets import Basket
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.poll_status(timeout=120, step=20)
 
         **See also**
@@ -281,7 +307,7 @@ class Basket(Asset, PositionedEntity):
         report_id = get(report, 'id')
         return self.poll_report(report_id, timeout, step)
 
-    @_error(ErrorMessage.UNINITIALIZED)
+    @_validate(ErrorMessage.UNINITIALIZED)
     def get_latest_rebalance_data(self) -> Dict:
         """
         Retrieve the most recent rebalance data for a basket
@@ -296,7 +322,7 @@ class Basket(Asset, PositionedEntity):
 
         >>> from gs_quant.markets.baskets import Basket
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.get_latest_rebalance_data()
 
         **See also**
@@ -305,7 +331,7 @@ class Basket(Asset, PositionedEntity):
         """
         return GsIndexApi.last_rebalance_data(self.id)
 
-    @_error(ErrorMessage.UNINITIALIZED)
+    @_validate(ErrorMessage.UNINITIALIZED)
     def get_latest_rebalance_date(self) -> dt.date:
         """
         Retrieve the most recent rebalance date for a basket
@@ -322,7 +348,7 @@ class Basket(Asset, PositionedEntity):
 
         >>> from gs_quant.markets.baskets import Basket
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.get_latest_rebalance_date()
 
         **See also**
@@ -332,7 +358,7 @@ class Basket(Asset, PositionedEntity):
         last_rebalance = GsIndexApi.last_rebalance_data(self.id)
         return dt.datetime.strptime(last_rebalance['date'], '%Y-%m-%d').date()
 
-    @_error(ErrorMessage.UNINITIALIZED)
+    @_validate(ErrorMessage.UNINITIALIZED)
     def get_rebalance_approval_status(self) -> str:
         """
         Retrieve the most recent rebalance submission's approval status
@@ -349,7 +375,7 @@ class Basket(Asset, PositionedEntity):
 
         >>> from gs_quant.markets.baskets import Basket
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.get_rebalance_approval_status()
 
         **See also**
@@ -359,7 +385,7 @@ class Basket(Asset, PositionedEntity):
         last_approval = GsIndexApi.last_rebalance_approval(self.id)
         return get(last_approval, 'status')
 
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def cancel_rebalance(self) -> Dict:
         """
         Cancel the most recent rebalance submission
@@ -374,7 +400,7 @@ class Basket(Asset, PositionedEntity):
 
         >>> from gs_quant.markets.baskets import Basket
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.cancel_rebalance()
 
         **See also**
@@ -383,11 +409,11 @@ class Basket(Asset, PositionedEntity):
         """
         return GsIndexApi.cancel_rebalance(self.id)
 
-    @_error(ErrorMessage.UNINITIALIZED)
+    @_validate(ErrorMessage.UNINITIALIZED)
     def get_corporate_actions(self,
                               start: dt.date = DateLimit.LOW_LIMIT.value,
                               end: dt.date = dt.date.today() + dt.timedelta(days=10),
-                              ca_type: [CorporateActionType] = CorporateActionType.to_list()) -> pd.DataFrame:
+                              ca_type: List[CorporateActionType] = CorporateActionType.to_list()) -> pd.DataFrame:
         """
         Retrieve corporate actions for a basket across a date range
 
@@ -407,7 +433,7 @@ class Basket(Asset, PositionedEntity):
         >>> from gs_quant.markets.baskets import Basket
         >>> from gs_quant.markets.indices_utils import CorporateActionType
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.get_corporate_actions(ca_type=[CorporateActionType.ACQUISITION])
 
         **See also**
@@ -419,13 +445,13 @@ class Basket(Asset, PositionedEntity):
         response = GsDataApi.query_data(query=query, dataset_id=IndicesDatasets.CORPORATE_ACTIONS.value)
         return pd.DataFrame(response)
 
-    @_error(ErrorMessage.UNINITIALIZED)
+    @_validate(ErrorMessage.UNINITIALIZED)
     def get_fundamentals(self,
                          start: dt.date = DateLimit.LOW_LIMIT.value,
                          end: dt.date = dt.date.today(),
                          period: FundamentalMetricPeriod = FundamentalMetricPeriod.ONE_YEAR.value,
                          direction: FundamentalMetricPeriodDirection = FundamentalMetricPeriodDirection.FORWARD.value,
-                         metrics: [FundamentalsMetrics] = FundamentalsMetrics.to_list()) -> pd.DataFrame:
+                         metrics: List[FundamentalsMetrics] = FundamentalsMetrics.to_list()) -> pd.DataFrame:
         """
         Retrieve fundamentals data for a basket across a date range
 
@@ -447,7 +473,7 @@ class Basket(Asset, PositionedEntity):
         >>> from gs_quant.markets.baskets import Basket
         >>> from gs_quant.markets.indices_utils import FundamentalsMetrics
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.get_corporate_actions(metrics=[FundamentalsMetrics.DIVIDEND_YIELD])
 
         **See also**
@@ -459,7 +485,7 @@ class Basket(Asset, PositionedEntity):
         response = GsDataApi.query_data(query=query, dataset_id=IndicesDatasets.BASKET_FUNDAMENTALS.value)
         return pd.DataFrame(response)
 
-    @_error(ErrorMessage.UNINITIALIZED)
+    @_validate(ErrorMessage.UNINITIALIZED)
     def get_live_date(self) -> Optional[dt.date]:
         """
         Retrieve basket's live date
@@ -472,12 +498,11 @@ class Basket(Asset, PositionedEntity):
 
         >>> from gs_quant.markets.baskets import Basket
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.get_live_date()
         """
         return self.__live_date
 
-    @_error(ErrorMessage.UNINITIALIZED)
     def get_type(self) -> Optional[SecAssetType]:
         """
         Retrieve basket type
@@ -490,12 +515,13 @@ class Basket(Asset, PositionedEntity):
 
         >>> from gs_quant.markets.baskets import Basket
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.get_type()
         """
-        return SecAssetType[self.__gs_asset_type.name.upper()]
+        if self.__gs_asset_type:
+            return SecAssetType[self.__gs_asset_type.name.upper()]
 
-    @_error(ErrorMessage.UNINITIALIZED)
+    @_validate(ErrorMessage.UNINITIALIZED)
     def get_url(self) -> str:
         """
         Retrieve url to basket's product page in Marquee
@@ -508,20 +534,71 @@ class Basket(Asset, PositionedEntity):
 
         >>> from gs_quant.markets.baskets import Basket
         >>>
-        >>> basket = Basket("GSMBXXXX")
+        >>> basket = Basket.get("GSMBXXXX")
         >>> basket.get_url()
         """
         env = '-dev' if 'dev' in get(GsSession, 'current.domain', '') else ''
         env = '-qa' if 'qa' in get(GsSession, 'current.domain', '') else env
         return f'https://marquee{env}.gs.com/s/products/{self.id}/summary'
 
+    @_validate(ErrorMessage.UNINITIALIZED, ErrorMessage.NON_ADMIN)
+    def add_factor_risk_report(self, risk_model_id: str, fx_hedged: bool):
+        """
+        Create and schedule a new factor risk report for your basket
+
+        :param risk_model_id: risk model identifier
+        :param fx_hedged: Assume basket is FX hedged
+
+        **Usage**
+
+        Create and schedule a new factor risk report for your basket
+
+        **Examples**
+
+        >>> from gs_quant.markets.baskets import Basket
+        >>>
+        >>> basket = Basket.get("GSMBXXXX")
+        >>> basket.add_factor_risk_report('AXUS4M', True)
+
+        **See also**
+
+        :func:`delete_factor_risk_report`
+        """
+        payload = CustomBasketRiskParams(risk_model=risk_model_id, fx_hedged=fx_hedged)
+        return GsIndexApi.update_risk_reports(payload)
+
+    @_validate(ErrorMessage.UNINITIALIZED, ErrorMessage.NON_ADMIN)
+    def delete_factor_risk_report(self, risk_model_id: str):
+        """
+        Delete an existing factor risk report for your basket
+
+        :param risk_model_id: risk model identifier for the report you'd like to delete
+
+        **Usage**
+
+        Delete an existing factor risk report for your basket
+
+        **Examples**
+
+        >>> from gs_quant.markets.baskets import Basket
+        >>>
+        >>> basket = Basket.get("GSMBXXXX")
+        >>> basket.delete_factor_risk_report('AXUS4M')
+
+        **See also**
+
+        :func:`add_factor_risk_report`
+        """
+        payload = CustomBasketRiskParams(risk_model=risk_model_id, delete=True)
+        return GsIndexApi.update_risk_reports(payload)
+
     @property
     def allow_ca_restricted_assets(self) -> Optional[bool]:
         """ Allow basket to have constituents that will not be corporate action adjusted in the future """
         return self.__allow_ca_restricted_assets
 
     @allow_ca_restricted_assets.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def allow_ca_restricted_assets(self, value: bool):
         self.__allow_ca_restricted_assets = value
 
@@ -531,7 +608,7 @@ class Basket(Asset, PositionedEntity):
         return self.__allow_limited_access_assets
 
     @allow_limited_access_assets.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def allow_limited_access_assets(self, value: bool):
         self.__allow_limited_access_assets = value
 
@@ -546,7 +623,7 @@ class Basket(Asset, PositionedEntity):
         return self.__currency
 
     @currency.setter
-    @_error(ErrorMessage.UNMODIFIABLE)
+    @_validate(ErrorMessage.UNMODIFIABLE)
     def currency(self, value: IndicesCurrency):
         self.__currency = value
 
@@ -556,7 +633,7 @@ class Basket(Asset, PositionedEntity):
         return self.__default_backcast
 
     @default_backcast.setter
-    @_error(ErrorMessage.UNMODIFIABLE)
+    @_validate(ErrorMessage.UNMODIFIABLE)
     def default_backcast(self, value: bool):
         self.__default_backcast = value
 
@@ -566,31 +643,41 @@ class Basket(Asset, PositionedEntity):
         return self.__description
 
     @description.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def description(self, value: str):
         self.__description = value
 
     @property
+    @_validate()
     def divisor(self) -> Optional[float]:
         """ Divisor to be applied to the overall position set """
-        self.__finish_populating_attributes_for_existing_basket()
         return self.__divisor
 
     @divisor.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def divisor(self, value: float):
-        self.__finish_populating_attributes_for_existing_basket()
         self.__initial_price = None
         self.__divisor = value
 
     @property
-    @_error(ErrorMessage.NON_INTERNAL)
+    @_validate()
+    def entitlements(self) -> Optional[BasketEntitlements]:
+        """ Basket entitlements """
+        return self.__entitlements
+
+    @entitlements.setter
+    @_validate(ErrorMessage.NON_ADMIN)
+    def entitlements(self, value: BasketEntitlements):
+        self.__entitlements = value
+
+    @property
+    @_validate(ErrorMessage.NON_INTERNAL)
     def flagship(self) -> Optional[bool]:
         """ If the basket is flagship (internal only) """
         return self.__flagship
 
     @flagship.setter
-    @_error(ErrorMessage.NON_INTERNAL)
+    @_validate(ErrorMessage.NON_INTERNAL)
     def flagship(self, value: bool):
         self.__flagship = value
 
@@ -605,92 +692,88 @@ class Basket(Asset, PositionedEntity):
         return self.__include_price_history
 
     @include_price_history.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def include_price_history(self, value: bool):
         self.__include_price_history = value
 
     @property
+    @_validate()
     def initial_price(self) -> Optional[float]:
         """ Initial price the basket it should start ticking at """
-        self.__finish_populating_attributes_for_existing_basket()
         return self.__initial_price
 
     @initial_price.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def initial_price(self, value: float):
-        self.__finish_populating_attributes_for_existing_basket()
         self.__divisor = None
         self.__initial_price = value
 
     @property
     def name(self) -> Optional[str]:
-        """ Display name of the basket """
+        """ Display name of the basket (must be <= 24 characters)"""
         return self.__name
 
     @name.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def name(self, value: str):
+        if len(value) > 24:
+            raise MqValueError(f'Basket name of {len(value)} characters is too long (must be <= 24 characters).')
         self.__name = value
 
     @property
     def parent_basket(self) -> Optional[str]:
         """ Ticker of the source basket, in case current basket composition is sourced from another marquee basket """
-        self.__finish_populating_attributes_for_existing_basket()
+        if has(self, '__clone_parent_id') and not has(self, '__parent_basket'):
+            self.__parent_basket = get(GsAssetApi.get_asset(self.__clone_parent_id), 'id')
         return self.__parent_basket
 
     @parent_basket.setter
-    @_error(ErrorMessage.UNMODIFIABLE)
+    @_validate(ErrorMessage.UNMODIFIABLE)
     def parent_basket(self, value: str):
-        self.__finish_populating_attributes_for_existing_basket()
-        self.__clone_parent_id = get(self.__get_gs_asset(value), 'id')
+        self.__clone_parent_id = get(__get_gs_asset(value), 'id')
         self.__parent_basket = value
 
     @property
+    @_validate()
     def position_set(self) -> Optional[PositionSet]:
         """ Information of constituents associated with the basket """
-        self.__finish_populating_attributes_for_existing_basket()
         return self.__position_set
 
     @position_set.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def position_set(self, value: PositionSet):
-        self.__finish_populating_attributes_for_existing_basket()
         self.__position_set = value
 
     @property
+    @_validate()
     def publish_to_bloomberg(self) -> Optional[bool]:
         """ If the basket should be published to Bloomberg """
-        self.__finish_populating_attributes_for_existing_basket()
         return self.__publish_to_bloomberg
 
     @publish_to_bloomberg.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def publish_to_bloomberg(self, value: bool):
-        self.__finish_populating_attributes_for_existing_basket()
         self.__publish_to_bloomberg = value
 
     @property
+    @_validate()
     def publish_to_factset(self) -> Optional[bool]:
         """ If the basket should be published to Factset """
-        self.__finish_populating_attributes_for_existing_basket()
         return self.__publish_to_factset
 
     @publish_to_factset.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def publish_to_factset(self, value: bool):
-        self.__finish_populating_attributes_for_existing_basket()
         self.__publish_to_factset = value
 
     @property
     def publish_to_reuters(self) -> Optional[bool]:
         """ If the basket should be published to Reuters """
-        self.__finish_populating_attributes_for_existing_basket()
         return self.__publish_to_reuters
 
     @publish_to_reuters.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def publish_to_reuters(self, value: bool):
-        self.__finish_populating_attributes_for_existing_basket()
         self.__publish_to_reuters = value
 
     @property
@@ -699,7 +782,7 @@ class Basket(Asset, PositionedEntity):
         return self.__return_type
 
     @return_type.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def return_type(self, value: ReturnType):
         self.__return_type = value
 
@@ -709,7 +792,7 @@ class Basket(Asset, PositionedEntity):
         return self.__reweight
 
     @reweight.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def reweight(self, value: bool):
         self.__reweight = value
 
@@ -719,7 +802,7 @@ class Basket(Asset, PositionedEntity):
         return self.__target_notional
 
     @target_notional.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def target_notional(self, value: float):
         self.__target_notional = value
 
@@ -729,7 +812,7 @@ class Basket(Asset, PositionedEntity):
         return self.__ticker
 
     @ticker.setter
-    @_error(ErrorMessage.UNMODIFIABLE)
+    @_validate(ErrorMessage.UNMODIFIABLE)
     def ticker(self, value: str):
         self.__validate_ticker(value)
         self.__ticker = value
@@ -740,7 +823,7 @@ class Basket(Asset, PositionedEntity):
         return self.__weighting_strategy
 
     @weighting_strategy.setter
-    @_error(ErrorMessage.NON_ADMIN)
+    @_validate(ErrorMessage.NON_ADMIN)
     def weighting_strategy(self, value: WeightingStrategy):
         self.__weighting_strategy = value
 
@@ -760,29 +843,35 @@ class Basket(Asset, PositionedEntity):
         response = GsIndexApi.rebalance(self.id, rebal_inputs)
         return response
 
-    def __finish_populating_attributes_for_existing_basket(self):
-        """ Populates all values not originally fetched during initialization due to required API calls """
-        if self.__populate_api_attrs:
-            position_set = GsAssetApi.get_latest_positions(self.id, PositionType.ANY)
-            report = get(self, '__latest_create_report', self.__get_latest_create_report())
-            self.__divisor = get(position_set, 'divisor')
-            self.__initial_price = get(GsIndexApi.initial_price(self.id, dt.date.today()), 'price')
-            self.__parent_basket = None if self.__clone_parent_id is None else \
-                get(GsAssetApi.get_asset(self.__clone_parent_id), 'id')
-            self.__position_set = PositionSet.from_target(position_set)
-            self.__publish_to_bloomberg = get(report, 'parameters.publish_to_bloomberg')
-            self.__publish_to_factset = get(report, 'parameters.publish_to_factset')
-            self.__publish_to_reuters = get(report, 'parameters.publish_to_reuters')
-            set_(self.__initial_state, 'divisor', self.__divisor)
-            set_(self.__initial_state, 'initial_price', self.__initial_price)
-            set_(self.__initial_state, 'position_set', self.__position_set)
-            set_(self.__initial_state, 'publish_to_bloomberg', self.__publish_to_bloomberg)
-            set_(self.__initial_state, 'publish_to_factset', self.__publish_to_factset)
-            set_(self.__initial_state, 'publish_to_reuters', self.__publish_to_reuters)
-            self.__initial_positions = set(deepcopy(self.__position_set.positions))
-            self.__populate_api_attrs = False
+    def __finish_initialization(self):
+        """ Fetches remaining data not retrieved during basket initialization """
+        if has(self, 'id'):
+            if not has(self, '__initial_positions'):
+                position_set = GsAssetApi.get_latest_positions(self.id, PositionType.ANY)
+                position_set = PositionSet.from_target(position_set)
+                self.__position_set = position_set
+                self.__divisor = get(position_set, 'divisor')
+                self.__initial_positions = set(deepcopy(self.__position_set.positions))
+                set_(self.__initial_state, 'divisor', self.__divisor)
+                set_(self.__initial_state, 'position_set', self.__position_set)
+            if not has(self.__initial_state, 'initial_price'):
+                initial_price = GsIndexApi.initial_price(self.id, dt.date.today())
+                self.__initial_price = get(initial_price, 'price')
+                set_(self.__initial_state, 'initial_price', self.__initial_price)
+            if not has(self.__initial_state, 'publish_to_bloomberg'):
+                report = get(self, '__latest_create_report', self.__get_latest_create_report())
+                self.__publish_to_bloomberg = get(report, 'parameters.publish_to_bloomberg')
+                self.__publish_to_factset = get(report, 'parameters.publish_to_factset')
+                self.__publish_to_reuters = get(report, 'parameters.publish_to_reuters')
+                set_(self.__initial_state, 'publish_to_bloomberg', self.__publish_to_bloomberg)
+                set_(self.__initial_state, 'publish_to_factset', self.__publish_to_factset)
+                set_(self.__initial_state, 'publish_to_reuters', self.__publish_to_reuters)
+            if not has(self, '__entitlements'):
+                self.__entitlements = BasketEntitlements.from_target(self.__initial_entitlements)
+        self.__set_error_messages()
 
-    def __get_gs_asset(self, identifier: str) -> GsAsset:
+    @staticmethod
+    def __get_gs_asset(identifier: str) -> GsAsset:
         """ Resolves basket identifier during initialization """
         response = GsAssetApi.resolve_assets(identifier=[identifier], fields=['id'], limit=1)[identifier]
         if len(response) == 0 or get(response, '0.id') is None:
@@ -865,7 +954,7 @@ class Basket(Asset, PositionedEntity):
         self.__name = get(kwargs, 'name')
         self.__parent_basket = get(kwargs, 'parent_basket')
         if self.__parent_basket is not None and self.__clone_parent_id is None:
-            self.__clone_parent_id = get(self.__get_gs_asset(self.__parent_basket), 'id')
+            self.__clone_parent_id = get(__get_gs_asset(self.__parent_basket), 'id')
         self.__position_set = get(kwargs, 'position_set')
         self.__publish_to_bloomberg = get(kwargs, 'publish_to_bloomberg', True)
         self.__publish_to_factset = get(kwargs, 'publish_to_factset', False)
@@ -874,17 +963,21 @@ class Basket(Asset, PositionedEntity):
         self.__target_notional = get(kwargs, 'target_notional', 10000000)
         self.__ticker = get(kwargs, 'ticker')
 
-    def __set_error_messages(self, user_is_admin: bool, user_is_internal: bool, existing_basket_initialized: bool):
+    def __set_error_messages(self):
         """ Errors to check for based on current user/basket state """
+        if len(get(self, '__error_messages', [])) > 0:
+            return
         errors = []
-        if not user_is_admin:
-            errors.append(ErrorMessage.NON_ADMIN)
-        if not user_is_internal:
+        user_tokens = get(GsUsersApi.get_current_user_info(), 'tokens', [])
+        if 'internal' not in user_tokens:
             errors.append(ErrorMessage.NON_INTERNAL)
-        if not existing_basket_initialized:
+        if not has(self, 'id'):
             errors.append(ErrorMessage.UNINITIALIZED)
         else:
             errors.append(ErrorMessage.UNMODIFIABLE)
+            tokens = set(get(self.__initial_entitlements, 'admin', []))
+            if not any(t in user_tokens for t in tokens):
+                errors.append(ErrorMessage.NON_ADMIN)
         self.__error_messages = set(errors)
 
     def __validate_ticker(self, ticker: str):
