@@ -65,37 +65,28 @@ class CorporateActionType(EnumBase, Enum):
 
 class CustomBasketStyles(EnumBase, Enum):
     """ Styles for Custom Baskets """
-    ASIA = 'Asia'
-    BESPOKE = 'Bespoke'
+    AD_HOC_DESK_WORK = 'Ad Hoc Desk Work'
+    CLIENT_CONSTRUCTED_WRAPPER = 'Client Constructed/Wrapper'
     CONSUMER = 'Consumer'
-    EM = 'EM'
     ENERGY = 'Energy'
+    ENHANCED_INDEX_SOLUTIONS = 'Enhanced Index Solutions'
     ESG = 'ESG'
-    ETF_REPLICATION = 'ETF Replication'
-    EU = 'EU'
     FACTORS = 'Factors'
     FINANCIALS = 'Financials'
-    FUNDAMENTAL = 'Fundamental'
+    FLAGSHIP = 'Flagship'
     GEOGRAPHIC = 'Geographic'
-    GLOBAL = 'Global'
     GROWTH = 'Growth'
-    HEALTHCARE = 'Healthcare'
+    HEALTHCARE = 'Health Care'
+    HEDGING = 'Hedging'
     INDUSTRIALS = 'Industrials'
-    INDUSTRY = 'Sub-Sectors / Smart Industries'
-    MACRO = 'Macro'
-    MACRO_SECTORS = 'Macro Sectors'
     MATERIALS = 'Materials'
-    MICRO_SECTORS = 'Micro Sectors'
     MOMENTUM = 'Momentum'
     PIPG = 'PIPG'
-    POSITIONING = 'Positioning'
-    SINGLE_STOCKS = 'Single Stocks'
+    SECTORS_INDUSTRIES = 'Sectors/Industries'
     SIZE = 'Size'
-    STRUCTURED_1_DELTA = 'Structured 1 Delta'
+    STRUCTURED_ONE_DELTA = 'Structured One Delta'
     THEMATIC = 'Thematic'
     TMT = 'TMT'
-    TOPICAL = 'Topical'
-    US = 'US'
     UTILITIES = 'Utilities'
     VALUE = 'Value'
     VOLATILITY = 'Volatility'
@@ -194,7 +185,7 @@ class ResearchBasketStyles(EnumBase, Enum):
     TACTICAL_RESEARCH = 'Tactical Research'
     THEMATIC = 'Thematic'
     US = 'US'
-    WAVEFRONT_COMPONENETS = 'Wavefront Components'
+    WAVEFRONT_COMPONENTS = 'Wavefront Components'
     WAVEFRONT_PAIRS = 'Wavefront Pairs'
     WAVEFRONTS = 'Wavefronts'
 
