@@ -15,10 +15,9 @@ under the License.
 """
 import datetime as dt
 import logging
-import pandas as pd
 from typing import Iterable, Optional, Union
 
-from .core import DataFrameWithInfo, ErrorValue, UnsupportedValue, FloatWithInfo, StringWithInfo, sort_risk
+from .core import DataFrameWithInfo, ErrorValue, UnsupportedValue, FloatWithInfo, StringWithInfo, sort_values
 from .measures import EqDelta, EqGamma, EqVega
 from gs_quant.base import InstrumentBase, RiskKey
 
@@ -26,14 +25,32 @@ _logger = logging.getLogger(__name__)
 __scalar_risk_measures = (EqDelta, EqGamma, EqVega)
 
 
-def __dataframe_handler(result: Iterable, mappings: tuple, risk_key: RiskKey, request_id: Optional[str] = None)\
+def __dataframe_handler(result: Iterable, mappings: tuple, risk_key: RiskKey, request_id: Optional[str] = None) \
         -> DataFrameWithInfo:
-    records = [{k: datum.get(v, (None if v == 'value' else '')) for k, v in mappings} for datum in result]
-    df = pd.DataFrame.from_records(records)
-    return DataFrameWithInfo(sort_risk(df, tuple(k for k, _ in mappings)), risk_key=risk_key, request_id=request_id)
+    first_row = next(iter(result), None)
+    if first_row is None:
+        return DataFrameWithInfo(risk_key=risk_key, request_id=request_id)
+
+    columns = ()
+    indices = [False] * len(first_row.keys())
+    mappings_lookup = {v: k for k, v in mappings}
+
+    for idx, src in enumerate(first_row.keys()):
+        if src in mappings_lookup:
+            indices[idx] = True
+            columns += ((mappings_lookup[src]),)
+
+    records = tuple(
+        sort_values((tuple(v for i, v in enumerate(r.values()) if indices[i]) for r in result), columns, columns)
+    )
+
+    df = DataFrameWithInfo(records, risk_key=risk_key, request_id=request_id)
+    df.columns = columns
+
+    return df
 
 
-def cashflows_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase, request_id: Optional[str] = None)\
+def cashflows_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase, request_id: Optional[str] = None) \
         -> DataFrameWithInfo:
     mappings = (
         ('payment_date', 'payDate'),
@@ -60,7 +77,7 @@ def cashflows_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBa
     return __dataframe_handler(result['cashflows'], mappings, risk_key, request_id=request_id)
 
 
-def error_handler(result: dict, risk_key: RiskKey, instrument: InstrumentBase, request_id: Optional[str] = None)\
+def error_handler(result: dict, risk_key: RiskKey, instrument: InstrumentBase, request_id: Optional[str] = None) \
         -> ErrorValue:
     error = result.get('errorString', 'Unknown error')
     if request_id:
@@ -75,7 +92,7 @@ def leg_definition_handler(result: dict, risk_key: RiskKey, instrument: Instrume
     return instrument.resolved(result, risk_key)
 
 
-def message_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase, request_id: Optional[str] = None)\
+def message_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase, request_id: Optional[str] = None) \
         -> StringWithInfo:
     return StringWithInfo(risk_key, result.get('message'), request_id=request_id)
 
@@ -147,8 +164,8 @@ def risk_by_class_handler(result: dict, risk_key: RiskKey, _instrument: Instrume
         return __dataframe_handler(classes, mappings, risk_key, request_id=request_id)
 
 
-def risk_vector_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase, request_id: Optional[str] = None)\
-        -> DataFrameWithInfo:
+def risk_vector_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
+                        request_id: Optional[str] = None) -> DataFrameWithInfo:
     assets = result['asset']
     # Handle equity risk measures which are really scalars
     if len(assets) == 1 and risk_key.risk_measure in __scalar_risk_measures:
@@ -162,12 +179,44 @@ def risk_vector_handler(result: dict, risk_key: RiskKey, _instrument: Instrument
         ('mkt_asset', 'asset'),
         ('mkt_class', 'class_'),
         ('mkt_point', 'point'),
+        ('mkt_quoting_style', 'quoteStyle'),
         ('value', 'value')
     )
 
     return __dataframe_handler(result['points'], mappings, risk_key, request_id=request_id)
 
 
+def risk_theta_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
+                       request_id: Optional[str] = None) -> FloatWithInfo:
+    return FloatWithInfo(risk_key, result['values'][0], request_id=request_id)
+
+
+def mdapi_table_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
+                        request_id: Optional[str] = None) -> DataFrameWithInfo:
+    coordinates = []
+    for r in result['rows']:
+        point = ';'.join(r['coordinate']['point']) if isinstance(r['coordinate']['point'], list) else ""
+        r['coordinate'].update({'point': point})
+        r['coordinate'].update({'value': r['value']})
+        r['coordinate'].update({'permissions': r['permissions']})
+        coordinates.append(r['coordinate'])
+
+    mappings = (('mkt_type', 'type'),
+                ('mkt_asset', 'asset'),
+                ('mkt_class', 'assetClass'),
+                ('mkt_point', 'point'),
+                ('mkt_quoting_style', 'quotingStyle'),
+                ('value', 'value'),
+                ('permissions', 'permissions'))
+
+    return __dataframe_handler(coordinates, mappings, risk_key, request_id=request_id)
+
+
+def market_handler(result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
+                   request_id: Optional[str] = None) -> StringWithInfo:
+    return StringWithInfo(risk_key, result.get('marketRef'), request_id=request_id)
+
+
 def unsupported_handler(_result: dict, risk_key: RiskKey, _instrument: InstrumentBase,
                         request_id: Optional[str] = None) -> UnsupportedValue:
     return UnsupportedValue(risk_key, request_id=request_id)
@@ -178,10 +227,13 @@ result_handlers = {
     'IRPCashflowTable': cashflows_handler,
     'LegDefinition': leg_definition_handler,
     'Message': message_handler,
+    'MDAPITable': mdapi_table_handler,
     'NumberAndUnit': number_and_unit_handler,
     'RequireAssets': required_assets_handler,
     'Risk': risk_handler,
     'RiskByClass': risk_by_class_handler,
     'RiskVector': risk_vector_handler,
+    'RiskTheta': risk_theta_handler,
+    'Market': market_handler,
     'Unsupported': unsupported_handler
 }
