@@ -58,7 +58,7 @@ def _compose(lhs: ResultInfo, rhs: ResultInfo) -> ResultInfo:
 
 
 def _value_for_date(result: Union[DataFrameWithInfo, SeriesWithInfo], date: Union[Iterable, dt.date]) -> \
-        Union[DataFrameWithInfo, ErrorValue, FloatWithInfo]:
+        Union[DataFrameWithInfo, ErrorValue, FloatWithInfo, SeriesWithInfo]:
     from gs_quant.markets import CloseMarket
 
     raw_value = result.loc[date]
@@ -228,8 +228,11 @@ class MultipleRiskMeasureResult(dict):
 
             instruments_equal = self.__instrument == other.__instrument
 
-            if not set(self.keys()).isdisjoint(other.keys()) and instruments_equal and not \
-                    set(self.dates).isdisjoint(other.dates):
+            self_dt = [list(self.values())[0].risk_key.date] if len(self.dates) == 0 else self.dates
+            other_dt = [list(other.values())[0].risk_key.date] if len(other.dates) == 0 else other.dates
+            dates_overlap = not set(self_dt).isdisjoint(other_dt)
+
+            if not set(self.keys()).isdisjoint(other.keys()) and instruments_equal and dates_overlap:
                 raise ValueError('Results overlap on risk measures, instruments or dates')
 
             all_keys = set(chain(self.keys(), other.keys()))
@@ -495,10 +498,14 @@ class PortfolioRiskResult(CompositeResultFuture):
         def as_multiple_result_futures(portfolio_result):
             if len(portfolio_result.__risk_measures) > 1:
                 return portfolio_result
-
-            mr_futures = [as_multiple_result_futures(f) if isinstance(f, PortfolioRiskResult) else
-                          MultipleRiskMeasureFuture(p, {portfolio_result.__risk_measures[0]: f})
-                          for p, f in zip(portfolio_result.__portfolio, portfolio_result.futures)]
+            mr_futures = []
+            for p, f in zip(portfolio_result.__portfolio, portfolio_result.futures):
+                if isinstance(f, PortfolioRiskResult):
+                    mr_futures.append(as_multiple_result_futures(f))
+                elif isinstance(f, MultipleRiskMeasureFuture):
+                    mr_futures.append(f)
+                else:
+                    mr_futures.append(MultipleRiskMeasureFuture(p, {portfolio_result.__risk_measures[0]: f}))
             return PortfolioRiskResult(portfolio_result.__portfolio, portfolio_result.__risk_measures, mr_futures)
 
         def set_value(dest_result, src_result, src_risk_measure):
@@ -514,16 +521,23 @@ class PortfolioRiskResult(CompositeResultFuture):
                         pass
 
         def first_value(portfolio_result):
-            return portfolio_result[next(iter(self.__portfolio.all_instruments))]
+            if len(portfolio_result.__risk_measures) > 1:
+                return next(iter(portfolio_result[next(iter(portfolio_result.portfolio.all_instruments))].values()))
+            else:
+                return portfolio_result[next(iter(portfolio_result.__portfolio.all_instruments))]
 
         if isinstance(other, (int, float)):
             return PortfolioRiskResult(self.__portfolio, self.__risk_measures, [f + other for f in self.futures])
         elif isinstance(other, PortfolioRiskResult):
-            if not _risk_keys_compatible(first_value(self), first_value(self)):
-                return ValueError('Results must have matching scenario and location')
+            if not _risk_keys_compatible(first_value(self), first_value(other)) and not \
+                    set(self.__portfolio.all_instruments).isdisjoint(other.__portfolio.all_instruments):
+                raise ValueError('Results must have matching scenario and location')
 
-            if not set(self.__risk_measures).isdisjoint(other.__risk_measures) and not \
-                    set(self.dates).isdisjoint(other.dates) and not \
+            self_dt = (first_value(self).risk_key.date,) if len(self.dates) == 0 else self.dates
+            other_dt = (first_value(other).risk_key.date,) if len(other.dates) == 0 else other.dates
+            dates_overlap = not set(self_dt).isdisjoint(other_dt)
+
+            if not set(self.__risk_measures).isdisjoint(other.__risk_measures) and dates_overlap and not \
                     set(self.__portfolio.all_instruments).isdisjoint(other.__portfolio.all_instruments):
                 raise ValueError('Results overlap on risk measures, instruments or dates')
 
@@ -661,7 +675,8 @@ class PortfolioRiskResult(CompositeResultFuture):
             multi_rm = True if len(self.risk_measures) > 1 else False
             port_depth_one = True if len(max(self.portfolio.all_paths, key=len)) == 1 else False
             if has_bucketed or has_cashflows:
-                res_df_cols = max([i._get_raw_df().columns.values for i in list(self)], key=len)
+                res_list = list(filter(None.__ne__, [i._get_raw_df() for i in list(self)]))
+                res_df_cols = max([i.columns.values for i in res_list], key=len)
                 res_df_cols = list(filter(lambda x: x not in ['dates', 'risk_measure'], res_df_cols))
                 return ori_df.set_index([p for p in df_cols if p not in res_df_cols])
             else:
