@@ -14,9 +14,9 @@ specific language governing permissions and limitations
 under the License.
 """
 
-from gs_quant.target.common import *
+from gs_quant.common import *
 import datetime
-from typing import Mapping, Tuple, Union
+from typing import Mapping, Tuple, Union, Optional
 from enum import Enum
 from gs_quant.base import Base, EnumBase, InstrumentBase, camel_case_translate, get_enum_value
 
@@ -46,10 +46,7 @@ class ComponentType(EnumBase, Enum):
     stackedBarChart = 'stackedBarChart'
     treemap = 'treemap'
     video = 'video'
-    webinar = 'webinar'
-    
-    def __repr__(self):
-        return self.value
+    webinar = 'webinar'    
 
 
 class WorkspaceType(EnumBase, Enum):    
@@ -57,10 +54,7 @@ class WorkspaceType(EnumBase, Enum):
     """Enum listing support workspace types."""
 
     cashboard = 'cashboard'
-    multiplot = 'multiplot'
-    
-    def __repr__(self):
-        return self.value
+    multiplot = 'multiplot'    
 
 
 class ComponentSelection(Base):
@@ -1540,8 +1534,8 @@ class SelectorComponentParameters(Base):
     @camel_case_translate
     def __init__(
         self,
-        container_ids: Tuple[str, ...],
         height: float,
+        container_ids: Tuple[str, ...] = None,
         default_option_index: float = None,
         options: Tuple[SelectorComponentOption, ...] = None,
         title: str = None,
@@ -1743,6 +1737,7 @@ class WorkspaceComponent(Base):
         hide: bool = None,
         tags: Tuple[str, ...] = None,
         selections: Tuple[ComponentSelection, ...] = None,
+        container_ids: Tuple[str, ...] = None,
         parameters: dict = None,
         name: str = None
     ):        
@@ -1752,6 +1747,7 @@ class WorkspaceComponent(Base):
         self.tags = tags
         self.__type = get_enum_value(ComponentType, type_)
         self.selections = selections
+        self.container_ids = container_ids
         self.parameters = parameters
         self.name = name
 
@@ -1807,6 +1803,16 @@ class WorkspaceComponent(Base):
         self._property_changed('selections')
         self.__selections = value        
 
+    @property
+    def container_ids(self) -> Tuple[str, ...]:
+        """The component ids of the containers the selector will fill using it's options."""
+        return self.__container_ids
+
+    @container_ids.setter
+    def container_ids(self, value: Tuple[str, ...]):
+        self._property_changed('container_ids')
+        self.__container_ids = value        
+
     @property
     def parameters(self) -> dict:
         return self.__parameters
