@@ -384,6 +384,9 @@ def test_date_range():
     with pytest.raises(MqValueError):
         date_range(pd.Series([1]), 0, 0)
 
+    with pytest.raises(MqTypeError):
+        date_range(pd.Series([1]), 0, 0, 'string')
+
 
 def test_prepend():
     x = pd.Series([1.0, 2.0, 3.0, 4.0, 5.0, 7.0], index=pd.date_range('2019-01-01', "2019-01-06"))
@@ -438,5 +441,14 @@ def test_bucketize():
     assert_series_equal(actual, expected, check_index_type=False)
 
 
+def test_day_count():
+    assert day_count(datetime.date(2021, 5, 7), datetime.date(2021, 5, 10)) == 1
+    assert day_count(datetime.date(2021, 5, 10), datetime.date(2021, 5, 14)) == 4
+    assert day_count(datetime.date(2021, 5, 10), datetime.date(2021, 5, 17)) == 5
+
+    with pytest.raises(MqValueError):
+        day_count(datetime.date(2021, 5, 7), '2021-05-10')
+
+
 if __name__ == "__main__":
     pytest.main(args=["test_datetime.py"])
