@@ -23,7 +23,7 @@ from .helper import *
 from .helper import _create_enum
 from ..datetime.date import DayCountConvention, PaymentFrequency, day_count_fraction
 from ..datetime.date import date_range as _date_range
-from ..errors import MqValueError
+from ..errors import MqValueError, MqTypeError
 
 """
 Date and time manipulation for timeseries, including date or time shifting, calendar operations, curve alignment and
@@ -488,6 +488,8 @@ def date_range(x: pd.Series, start_date: Union[date, int], end_date: Union[date,
     :func:`day` :func: `lag`
 
     """
+    if not isinstance(weekdays_only, bool):
+        raise MqTypeError('expected a boolean value for "weekdays_only"')
     if not (x.index.is_all_dates or all(map(lambda a: isinstance(a, date), x.index.values))):
         raise MqValueError('input is not a time series')
 
@@ -615,3 +617,17 @@ def bucketize(series: pd.Series, aggregate_function: AggregateFunction, period:
     frequency = period.value[0].upper()
     agg = aggregate_function.value
     return series.resample(frequency).apply(agg)
+
+
+@plot_function
+def day_count(first: datetime.date, second: datetime.date) -> int:
+    """
+    Counts the number of business days between two dates. Monday through Friday are considered to be business days.
+
+    :param first: first date
+    :param second: second date
+    :return: number of business days between first and second
+    """
+    if not (isinstance(first, datetime.date) and isinstance(second, datetime.date)):
+        raise MqValueError('inputs must be dates')
+    return np.busday_count(first, second)
